@@ -67,4 +67,4 @@ class NestedMountedVolumeSerializer(WritableNestedSerializer):
 
     class Meta:
         model = MountedVolume
-        fields = ["id", "url", "display", "size", "path"]
\ No newline at end of file
+        fields = ["id", "url", "display", "mount_point"]
\ No newline at end of file
