@@ -65,17 +65,16 @@ class PartitionSerializer(serializers.ModelSerializer):
 
 class MountedVolumeSerializer(serializers.ModelSerializer):
     fs = NestedFilesystemSerializer(required=False, allow_null=True)
-    partition = NestedPartitionSerializer(required=False, allow_null=True)
+    device = NestedDeviceSerializer(required=False, allow_null=True)
 
     class Meta:
         model = MountedVolume
         fields = (
             "id",
-            "partition",
-            "fs",
-            "size",
-            "path",
-            "label",
+            "device",
+            "mount_point",
+            "fs_type",
+            "options",
             "description",
             "created",
             "last_updated",
