@@ -305,10 +305,12 @@ class PartitionTemplateForm(NetBoxModelForm):
         help_text="The Filesystem of the Volume e.g. ext4",
     )
     fs_options = CharField(
+        required=False,
         label="FS Options",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
     )
     label = CharField(
+        required=False,
         label="Partition Label",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
     )
@@ -344,10 +346,15 @@ class PartitionTemplateForm(NetBoxModelForm):
         print(f"drive: {self.cleaned_data['drive']}")
         print(f"ID OF drive: {self.cleaned_data['drive'].id}")
         print(f"ID OF drive: {self.cleaned_data['drive'].cluster}")
-        # drive = Drive.objects.create()
+        new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
+        device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
+        print(f"Partition Count: {new_partition_count}")
+        print(f"Device Name: {device_name_prefix}")
+        device_name = device_name_prefix + new_partition_count
 
-        linux_device = LinuxDevice.objects.create(device='/dev/sda1', type='efi')
-        # partition = Partition.objects.create(drive=self.cleaned_data['drive'].id, device=linux_device, size=self.cleaned_data['size'], type='vfat')
+        linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
+
+        MountedVolume.objects.create(device=linux_device, path=self.cleaned_data['path'], fs=self.cleaned_data['fs'],)
 
         self.instance.drive = self.cleaned_data['drive']
         self.instance.device = linux_device
@@ -356,7 +363,6 @@ class PartitionTemplateForm(NetBoxModelForm):
 
         # print(f"{self.cleaned_data['size']}")
         return partition
-        # return None
 
 
 class VolumeSimpleForm(NetBoxModelForm):
