@@ -192,16 +192,18 @@ class Migration(migrations.Migration):
                 ("device",
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="device_mounted_volume",
                                    to="netbox_storage.LinuxDevice")),
-                ("path", models.CharField(max_length=255)),
-                ("fs",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_linux',
+                ("mount_point", models.CharField(max_length=255)),
+                ("fs_type",
+                 models.ForeignKey(blank=True,
+                                   null=True,
+                                   on_delete=models.deletion.CASCADE,
+                                   related_name='fs_mounted_volume',
                                    to='netbox_storage.filesystem')),
-                ("size", models.FloatField()),
+                ("options", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
-                ("label", models.CharField(max_length=255)),
             ],
             options={
-                "ordering": ("path", "fs", "id"),
+                "ordering": ("device", "mount_point", "fs_type", "options"),
             },
         ),
         migrations.CreateModel(
