@@ -313,21 +313,19 @@ class MountedVolume(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='device_mounted_volume',
     )
-    size = models.FloatField(
-        verbose_name="Size (GB)"
-    )
-    path = models.CharField(
+    mount_point = models.CharField(
         max_length=255,
     )
-    label = models.CharField(
-        max_length=255,
-    )
-    fs = models.ForeignKey(
+    fs_type = models.ForeignKey(
         Filesystem,
         on_delete=models.CASCADE,
-        related_name="fs_linux",
+        related_name="fs_mounted_volume",
         verbose_name="Filesystem",
     )
+    options = models.CharField(
+        max_length=255,
+        blank=True,
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -335,9 +333,9 @@ class MountedVolume(NetBoxModel):
 
     clone_fields = [
         "device",
-        "size",
-        "path",
-        "fs",
+        "mount_point",
+        "fs_type",
+        "options",
         "description",
     ]
 
@@ -345,10 +343,10 @@ class MountedVolume(NetBoxModel):
         return reverse("plugins:netbox_storage:mountedvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return f"{self.device.device}"
+        return f"Filesystem Table Entry: {self.device} mounted to {self.path}"
 
     class Meta:
-        ordering = ("size", "path", "description")
+        ordering = ("device", "mount_point", "fs_type", "options", "description")
 
 
 class StorageConfigurationLinuxVolume(NetBoxModel):
