@@ -1,7 +1,7 @@
 import logging
 
 from extras.plugins import PluginTemplateExtension
-from netbox_storage.models import PhysicalVolume, LogicalVolume, MountedVolume, StorageConfigurationLinuxVolume, \
+from netbox_storage.models import PhysicalVolume, LogicalVolume, StorageConfigurationLinuxVolume, \
     TemplateConfigurationLinuxVolume, Drive, Partition
 
 
@@ -53,10 +53,12 @@ class TemplateVolumeConfig(PluginTemplateExtension):
             print(drive_id['drive'])
             drives_id.append(drive_id['drive'])
             if Partition.objects.filter(drive_id=drive_id['drive']).count() == 0:
-                lonely_drive.append(Drive.objects.get(pk__in=drive_id['drive']))
+                drive = Drive.objects.get(pk=drive_id['drive'])
+                print(f"Lonely Drive: {drive}")
+                lonely_drive.append(drive)
 
         partitions = Partition.objects.filter(drive_id__in=drives_id)
-        print(f"{Partition.objects.all()}")
+        print(f"Lonely Drives: {lonely_drive}")
         print(f"Partitions: {partitions}")
         print(f"drives: {drives_id}")
         return self.render(
