@@ -3,7 +3,7 @@ from netbox.views import generic
 from netbox_storage.forms import LVMSimpleForm, VolumeSimpleForm, LinuxVolumeSimpleForm
 from netbox_storage.forms.template import LinuxVolumeTemplateForm, LVMTemplateForm, DriveTemplateForm, \
     PartitionTemplateForm
-from netbox_storage.models import Drive, StorageConfigurationLinuxVolume, TemplateConfigurationLinuxVolume
+from netbox_storage.models import Drive, StorageConfigurationLinuxVolume, TemplateConfigurationLinuxVolume, Partition
 
 
 class LVMAddTemplateView(generic.ObjectEditView):
@@ -29,5 +29,5 @@ class AddTemplateDriveView(generic.ObjectEditView):
 
 
 class AddTemplatePartitionView(generic.ObjectEditView):
-    queryset = TemplateConfigurationLinuxVolume.objects.all()
+    queryset = Partition.objects.all()
     form = PartitionTemplateForm
